{% load i18n %}
{% blocktrans %}
    <p>Again, please accept our apologies for any inconvenience that we cased you.</p>
    <p>If you would like to change your feedback or reconsider your out out decision you can do that anytime.</p>
{% endblocktrans %}
