{% load i18n %}
{% blocktrans %}
    <p>We're sorry that we overstepped and made our messages inconvenient to you. Please accept our apologies.</p>
    <P>We're trying to make them relevant to you and improve overall process so you can benefit from our messaging.</P>
    <p>We really want to learn from our failures and we are — us, humans here — reading every opt-out response.
        We really appreciate all the feedback you can give us.</p>
{% endblocktrans %}
