{% extends "django_opt_out/base.html" %}
{% load bootstrap i18n %}
{% block content %}
    <div class="container">
    <div class="row">
        <div class="col-md-8 offset-md-2">
            <div class="card">
                <h4 class="card-header">{% blocktrans %}Your Opt-out was removed{% endblocktrans %}</h4>
                <div class="card-body">
                    <p>{% blocktrans %}Thank you for changing your mind :){% endblocktrans %}</p>
                    <p><a href="https://www.youtube.com/watch?v=UPw-3e_pzqU">{% blocktrans %}You are back in!{% endblocktrans %}</a></p>
                </div>
            </div>
        </div>
    </div>
{% endblock %}
